@@ -89,6 +89,7 @@ sub gst_service_sysv_get_paths
        "ubuntu-6.06"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "ubuntu-6.10"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "ubuntu-7.04"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
+       "ubuntu-7.10"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        
        "suse-7.0"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d", "../"],
        "suse-9.0"     => ["$gst_prefix/etc/init.d", "$gst_prefix/etc/init.d", "../"],
@@ -166,6 +167,7 @@ sub gst_service_sysv_get_runlevels
        "ubuntu-6.06"    => [2, 3],
        "ubuntu-6.10"    => [2, 3],
        "ubuntu-7.04"    => [2, 3],
+       "ubuntu-7.10"    => [2, 3],
        
        "suse-7.0"       => [3, 5],
        "suse-9.0"       => [3, 5],
@@ -242,6 +244,7 @@ sub gst_service_get_runlevel_roles
      "ubuntu-6.06"    => "debian-2.2",
      "ubuntu-6.10"    => "debian-2.2",
      "ubuntu-7.04"    => "debian-2.2",
+     "ubuntu-7.10"    => "debian-2.2",
           
      "suse-7.0"       => "redhat-5.2",
      "suse-9.0"       => "redhat-5.2",
@@ -1721,6 +1724,7 @@ sub gst_service_get_status
        "ubuntu-6.06"  => \&gst_service_debian_get_status,
        "ubuntu-6.10"  => \&gst_service_debian_get_status,
        "ubuntu-7.04"  => \&gst_service_debian_get_status,
+       "ubuntu-7.10"  => \&gst_service_debian_get_status,
               
        "redhat-5.2"   => \&gst_service_redhat_get_status,
        "redhat-6.0"   => \&gst_service_redhat_get_status,
